@@ -6,7 +6,11 @@
 
 #include <QUrl>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "qquickwebenginedownloaditem.h"
+#else
+#include <private/qquickwebenginedownloadrequest_p.h>
+#endif
 
 DownloadManager::DownloadManager() = default;
 
@@ -16,18 +20,18 @@ DownloadManager &DownloadManager::instance()
     return instance;
 }
 
-void DownloadManager::addDownload(QQuickWebEngineDownloadItem *download)
+void DownloadManager::addDownload(std::unique_ptr<DownloadItem> &&download)
 {
-    m_downloads.push_back(download);
+    m_downloads.push_back(std::move(download));
 }
 
 void DownloadManager::removeDownload(const int index)
 {
     m_downloads.at(index)->cancel();
-    m_downloads.removeAt(index);
+    m_downloads.erase(m_downloads.begin() + index);
 }
 
-const QVector<QQuickWebEngineDownloadItem *> &DownloadManager::downloads()
+const std::vector<std::unique_ptr<DownloadItem>> &DownloadManager::downloads()
 {
     return m_downloads;
 }
